package at.ac.uibk.gitsearch.service.criteria;

import java.io.Serializable;
import java.util.Objects;
import tech.jhipster.service.Criteria;
import tech.jhipster.service.filter.Filter;
import tech.jhipster.service.filter.LongFilter;
import tech.jhipster.service.filter.StringFilter;

/**
 * Criteria class for the {@link at.ac.uibk.gitsearch.domain.SavedSearches} entity. This class is used
 * in {@link at.ac.uibk.gitsearch.web.rest.SavedSearchesResource} to receive all the possible filtering options from
 * the Http GET request parameters.
 * For example the following could be a valid request:
 * {@code /saved-searches?id.greaterThan=5&attr1.contains=something&attr2.specified=false}
 * As Spring is unable to properly convert the types, unless specific {@link Filter} class are used, we need to use
 * fix type specific filters.
 */
@SuppressWarnings(
    {
        "PMD.GodClass",
        "PMD.AvoidFieldNameMatchingMethodName",
        "PMD.FieldDeclarationsShouldBeAtStartOfClass",
        "PMD.ShortMethodName",
        "PMD.ConfusingTernary",
    }
)
public class SavedSearchesCriteria implements Serializable, Criteria {

    private static final long serialVersionUID = 1L;

    private LongFilter id;

    private StringFilter name;

    private StringFilter jsonQuery;

    private LongFilter userId;

    private Boolean distinct;

    public SavedSearchesCriteria() {}

    public SavedSearchesCriteria(SavedSearchesCriteria other) {
        this.id = other.id == null ? null : other.id.copy();
        this.name = other.name == null ? null : other.name.copy();
        this.jsonQuery = other.jsonQuery == null ? null : other.jsonQuery.copy();
        this.userId = other.userId == null ? null : other.userId.copy();
        this.distinct = other.distinct;
    }

    @Override
    public SavedSearchesCriteria copy() {
        return new SavedSearchesCriteria(this);
    }

    public LongFilter getId() {
        return id;
    }

    public LongFilter id() {
        if (id == null) {
            id = new LongFilter();
        }
        return id;
    }

    public void setId(LongFilter id) {
        this.id = id;
    }

    public StringFilter getName() {
        return name;
    }

    public StringFilter name() {
        if (name == null) {
            name = new StringFilter();
        }
        return name;
    }

    public void setName(StringFilter name) {
        this.name = name;
    }

    public StringFilter getJsonQuery() {
        return jsonQuery;
    }

    public StringFilter jsonQuery() {
        if (jsonQuery == null) {
            jsonQuery = new StringFilter();
        }
        return jsonQuery;
    }

    public void setJsonQuery(StringFilter jsonQuery) {
        this.jsonQuery = jsonQuery;
    }

    public LongFilter getUserId() {
        return userId;
    }

    public LongFilter userId() {
        if (userId == null) {
            userId = new LongFilter();
        }
        return userId;
    }

    public void setUserId(LongFilter userId) {
        this.userId = userId;
    }

    public Boolean getDistinct() {
        return distinct;
    }

    public void setDistinct(Boolean distinct) {
        this.distinct = distinct;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final SavedSearchesCriteria that = (SavedSearchesCriteria) o;
        return (
            Objects.equals(id, that.id) &&
            Objects.equals(name, that.name) &&
            Objects.equals(jsonQuery, that.jsonQuery) &&
            Objects.equals(userId, that.userId) &&
            Objects.equals(distinct, that.distinct)
        );
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, name, jsonQuery, userId, distinct);
    }

    // prettier-ignore
    @Override
    public String toString() {
        return "SavedSearchesCriteria{" +
            (id != null ? "id=" + id + ", " : "") +
            (name != null ? "name=" + name + ", " : "") +
            (jsonQuery != null ? "jsonQuery=" + jsonQuery + ", " : "") +
            (userId != null ? "userId=" + userId + ", " : "") +
            (distinct != null ? "distinct=" + distinct + ", " : "") +
            "}";
    }
}
