import { Injectable } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { Resolve, ActivatedRouteSnapshot, Router } from '@angular/router';
import { Observable, of, EMPTY } from 'rxjs';
import { mergeMap } from 'rxjs/operators';

import { IReviewHistoryEntry, ReviewHistoryEntry } from '../review-history-entry.model';
import { ReviewHistoryEntryService } from '../service/review-history-entry.service';

@Injectable({ providedIn: 'root' })
export class ReviewHistoryEntryRoutingResolveService implements Resolve<IReviewHistoryEntry> {
  constructor(protected service: ReviewHistoryEntryService, protected router: Router) {}

  resolve(route: ActivatedRouteSnapshot): Observable<IReviewHistoryEntry> | Observable<never> {
    const id = route.params['id'];
    if (id) {
      return this.service.find(id).pipe(
        mergeMap((reviewHistoryEntry: HttpResponse<ReviewHistoryEntry>) => {
          if (reviewHistoryEntry.body) {
            return of(reviewHistoryEntry.body);
          } else {
            this.router.navigate(['404']);
            return EMPTY;
          }
        })
      );
    }
    return of(new ReviewHistoryEntry());
  }
}
