import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { isPresent } from 'app/core/util/operators';
import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { createRequestOption } from 'app/core/request/request-util';
import { IUserWatchList, getUserWatchListIdentifier } from '../user-watch-list.model';

export type EntityResponseType = HttpResponse<IUserWatchList>;
export type EntityArrayResponseType = HttpResponse<IUserWatchList[]>;

@Injectable({ providedIn: 'root' })
export class UserWatchListService {
  protected resourceUrl = this.applicationConfigService.getEndpointFor('api/user-watch-lists');

  constructor(protected http: HttpClient, protected applicationConfigService: ApplicationConfigService) {}

  create(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.post<IUserWatchList>(this.resourceUrl, userWatchList, { observe: 'response' });
  }

  update(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.put<IUserWatchList>(`${this.resourceUrl}/${getUserWatchListIdentifier(userWatchList) as number}`, userWatchList, {
      observe: 'response',
    });
  }

  partialUpdate(userWatchList: IUserWatchList): Observable<EntityResponseType> {
    return this.http.patch<IUserWatchList>(`${this.resourceUrl}/${getUserWatchListIdentifier(userWatchList) as number}`, userWatchList, {
      observe: 'response',
    });
  }

  find(id: number): Observable<EntityResponseType> {
    return this.http.get<IUserWatchList>(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  query(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IUserWatchList[]>(this.resourceUrl, { params: options, observe: 'response' });
  }

  delete(id: number): Observable<HttpResponse<{}>> {
    return this.http.delete(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  addUserWatchListToCollectionIfMissing(
    userWatchListCollection: IUserWatchList[],
    ...userWatchListsToCheck: (IUserWatchList | null | undefined)[]
  ): IUserWatchList[] {
    const userWatchLists: IUserWatchList[] = userWatchListsToCheck.filter(isPresent);
    if (userWatchLists.length > 0) {
      const userWatchListCollectionIdentifiers = userWatchListCollection.map(
        userWatchListItem => getUserWatchListIdentifier(userWatchListItem)!
      );
      const userWatchListsToAdd = userWatchLists.filter(userWatchListItem => {
        const userWatchListIdentifier = getUserWatchListIdentifier(userWatchListItem);
        if (userWatchListIdentifier == null || userWatchListCollectionIdentifiers.includes(userWatchListIdentifier)) {
          return false;
        }
        userWatchListCollectionIdentifiers.push(userWatchListIdentifier);
        return true;
      });
      return [...userWatchListsToAdd, ...userWatchListCollection];
    }
    return userWatchListCollection;
  }
}
