import { ProjectDTO } from './project-dto.model';
import { MetadataFileDTO } from './metadata-file-dto.model';
import { UserProvidedMetadataDTO } from './user-provided-metadata-dto.model';

export interface SearchStatisticsDTO {
  views?: number;
  downloads?: number;
  badgeRewarded?: boolean;
}

export interface SearchResultDTO {
  exerciseId: string;
  project: ProjectDTO;
  file: MetadataFileDTO;
  metadata: UserProvidedMetadataDTO;
  ranking5: number;
  supportedActions: PluginActionInfo[];
  views: number;
  downloads: number;
  searchStatistics?: SearchStatisticsDTO;
}

export interface ExtendedSearchResultDTO extends SearchResultDTO {
  // thesis
  views: number;
  downloads: number;

  numberOfWatchlistEntries: number;
  badgeRewarded: boolean;
  numberOfLikes: number;
  userHasLiked: boolean;
}

export function getPathOfExerciseId(exerciseId: string): string {
  if (exerciseId) {
    const colonPos = exerciseId.indexOf(':"');
    if (colonPos >= 0) return exerciseId.slice(colonPos + 1);
  }
  return '';
}

export interface PluginActionInfo {
  plugin: string;
  action: string;
  commandName: string;
}

export function equalPluginActionInfo(a: PluginActionInfo, b: PluginActionInfo): boolean {
  return a.action === b.action && a.commandName === b.commandName && a.plugin === b.plugin;
}
